@@ -64,7 +64,7 @@ encoded, requesting it does not require recursion any more. Non-recursive[^regex
 [regular expressions](https://en.wikipedia.org/wiki/Regular_expression) become a natural candidate
 for the request language. The current version of Paroxython explores this option. The regular
 expression patterns are processed in `paroxython.parse_program` on the basis of the definitions
-listed in [`spec.md`](https://repo/paroxython/resources/spec.md).
+listed in `spec.md`.
 
 [^regex-recursion]: Although nowadays, numerous flavours of regex engines support recursion,
 the complexity of writing, reading and maintaining any pattern using it would quickly go through the
@@ -252,7 +252,7 @@ def flatten_node(
         path (str, optional): The path of the current node. Defaults to `""`.
         remove_context (Callable, optional): A function removing the node context encoded in the
             result of `ast3.dump()`.
-            [Not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+            [Not to be explicitly provided.](developer_manual/index.html#default-argument-trick)
             Defaults to `regex.compile(r", ctx=.+?\(\)").sub`.
 
     Returns:
@@ -302,7 +302,7 @@ def simplify_negative_literals(
 ) -> str:
     """[Simplify the negative literals](#negative-literal-simplification) of a given flat AST.
 
-    Argument `sub` [not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+    Argument `sub` [not to be explicitly provided.](developer_manual/index.html#default-argument-trick)
     """
     return sub(r"\1/_type=Num\2\1/n=-\3", flat_ast)
 
