@@ -23,7 +23,7 @@ def labelled_programs(
         search_imported_program_name (Callable, optional): A function taking a label name and, in
             the case it starts with `"import:"` or `"import_module:"`, returns a match object
             whose first group is the name of the imported program.
-            [Not to be explicitly provided.](docs_developer_manual/index.html#default-argument-trick)
+            [Not to be explicitly provided.](developer_manual/index.html#default-argument-trick)
         print_performances (bool): If `True`, ends with a call to
             `paroxython.parse_program.ProgramParser.print_performances`. Defaults to `False`.
         **kwargs: May include the keyword arguments `cleanup_strategy`, `skip_pattern`,
@@ -67,15 +67,16 @@ def generate_labelled_sources(programs: Programs) -> Iterator:
     for program in programs:
         yield Source(f"# {separator}\n# {program.name}\n# {separator}")
         lines = program.source.splitlines()
-        comments: List[Set[str]] = [set() for _ in lines]
-        for label in program.labels:
-            for span in label.spans:
-                span_length = span.end - span.start
-                span_suffix = f" (-> +{span_length})" if span_length else ""
-                comments[span.start - 1].add(f"{label.name}{span_suffix}")
-        for (i, comment) in enumerate(comments):
-            if comment:
-                lines[i] += " # " + ", ".join(sorted(comment))
+        if lines:
+            comments: List[Set[str]] = [set() for _ in lines]
+            for label in program.labels:
+                for span in label.spans:
+                    span_length = span.end - span.start
+                    span_suffix = f" (-> +{span_length})" if span_length else ""
+                    comments[span.start - 1].add(f"{label.name}{span_suffix}")
+            for (i, comment) in enumerate(comments):
+                if comment:
+                    lines[i] += " # " + ", ".join(sorted(comment))
         yield Source("\n".join(lines + [""]))
 
 
