@@ -4,9 +4,8 @@ Translate labels into taxa.
 ## Description
 
 This step comes after `paroxython.label_programs` has tagged a program with the **labels** specified
-in [`spec.md`](https://repo/paroxython/resources/spec.md). Its purpose is to convert these labels
-into **taxa** based on the rules defined (by default) in
-[`taxonomy.tsv`](https://repo/paroxython/resources/taxonomy.tsv).
+in `spec.md`. Its purpose is to convert these labels into **taxa** based on the rules defined (by
+default) in `taxonomy.tsv`.
 
 ## Example
 
@@ -37,7 +36,7 @@ These labels are low-level tags, intended for internal use only. They still need
 into the following taxa, which are the only tags of interest to the end user. For instance,
 `"addition_operator"` will be translated into `"operator/arithmetic/addition"` (note that, unlike
 a label, a taxon may feature one or several slashes, which indicate the nesting of notions). More
-examples are given in the dedicated [section](docs_user_manual/index.html#taxonomy) of the user manual.
+examples are given in the dedicated [section](user_manual/index.html#taxonomy) of the user manual.
 
 In fact, both labels and taxa are couples:
 
@@ -132,7 +131,11 @@ __pdoc__ = {
 
 
 class Taxonomy:
-    def __init__(self, taxonomy_path: Optional[Path] = None, **kwargs,) -> None:
+    def __init__(
+        self,
+        taxonomy_path: Optional[Path] = None,
+        **kwargs,
+    ) -> None:
         r"""Read and pre-process the taxonomy specifications.
 
         Args:
@@ -144,8 +147,7 @@ class Taxonomy:
                 Defaults to `None`.
 
         Description:
-            1. Read the taxonomy, falling back to the provided default
-            [`taxonomy.tsv`](https://repo/paroxython/resources/taxonomy.tsv).
+            1. Read the taxonomy, falling back to the provided default `taxonomy.tsv`.
             2. Drop the part starting with the string `"-- EOF"`, if any (this pre-processing
             allows you to leave notes or drafts at the end of the file).
             3. Distribute the remaining rows into two different accumulators, depending on the
