@@ -49,7 +49,7 @@ from .user_types import (
     AssessedPrograms,
     Command,
     Criterion,
-    JsonDatabase,
+    JsonTagDatabase,
     Operation,
     ProgramNames,
 )
@@ -68,7 +68,7 @@ class MalformedData(Exception):
 class Recommendations:
     def __init__(
         self,
-        db: JsonDatabase,
+        db: JsonTagDatabase,
         base_path: Optional[Path] = None,
         title_format: str = "`{name}`",
         **kwargs,
@@ -76,8 +76,8 @@ class Recommendations:
         r"""Initialize a recommendation system for the given database of programs tagged with taxa.
 
         Args:
-            db (JsonDatabase): A Python dictionary containing the JSON structure constructed by
-                `paroxython.make_db.Database`, i.e. the result of the parsing, labelling and
+            db (JsonTagDatabase): A Python dictionary containing the JSON structure constructed by
+                `paroxython.make_db.TagDatabase`, i.e. the result of the parsing, labelling and
                 taxon-ifying of a set of programs
                 ([example](https://repo/examples/simple/programs_db.json)).
                 The execution relies on the fields `programs`, `taxa`, `importations` and
@@ -180,11 +180,9 @@ class Recommendations:
         self.assessed_programs = self.assess(self.selected_programs)
 
     def parse_data(
-        # fmt: off
         self,
         data: Union[str, List[Criterion]],
-        operation: Operation
-        # fmt: on
+        operation: Operation,
     ) -> List[Criterion]:
         """Retrieve the list of criteria to which to apply the given operation.
 
@@ -324,7 +322,8 @@ if __name__ == "__main__":
     json = __import__("json")
     program_path = Path("../algo/programs")
     rec = Recommendations(
-        db=json.loads(Path(f"{program_path}_db.json").read_text()), base_path=program_path.parent,
+        db=json.loads(Path(f"{program_path}_db.json").read_text()),
+        base_path=program_path.parent,
     )
     rec.run_pipeline(ast.literal_eval(Path(f"{program_path}_pipe.py").read_text()))
     output_path = Path(f"{program_path}_recommendations.md")
